#!/bin/bash
#************************ Warning **********************************
#*                                                                 *
#* This configuration is property of OPEN SOURCE CONSULTING, INC.  *
#* Don't distribute this to other project.                         *
#*                                                                 *
#* Contact jchoi@osci.kr(http://www.osci.kr)                       *
#*******************************************************************

# This is tomcat env.sh for iosp by Open Source Consulting, Inc

export DATE=`date +%Y%m%d_%H%M%S`

## Set Tomcat base env
export JAVA_HOME=/etc/alternatives/java_sdk_1.8.0
export SERVER_NAME=splace01
export CATALINA_HOME=/opt/apache-tomcat
export CATALINA_BASE=/workspace/aksw/was/$SERVER_NAME
export LOG_BASE=/workspace/aklogs/was/$SERVER_NAME
export PORT_OFFSET=10000
export COMP_USER=wasadm

## Set Port Configuration
#########################################
#  Default Ports are as below      	#
#  HTTP_PORT : 8080			#
#  SSL_PORT : 8443			#
#  SHUTDOWN_PORT : 8005			#
#########################################

export HTTP_PORT=$(expr 8080 + $PORT_OFFSET)
export AJP_PORT=$(expr 8009 + $PORT_OFFSET)
export SSL_PORT=$(expr 8443 + $PORT_OFFSET)
export SHUTDOWN_PORT=$(expr 8005 + $PORT_OFFSET)
export JMX_PORT=$(expr 8555 + $PORT_OFFSET)

if [ "x$JAVA_OPTS" = "x" ]; then
   JAVA_OPTS="-server"
   JAVA_OPTS="$JAVA_OPTS -Dserver=$SERVER_NAME"
   JAVA_OPTS="$JAVA_OPTS -Dhttp.port=$HTTP_PORT"
   JAVA_OPTS="$JAVA_OPTS -Dajp.port=$AJP_PORT"
   JAVA_OPTS="$JAVA_OPTS -Dssl.port=$SSL_PORT"
   JAVA_OPTS="$JAVA_OPTS -Dshutdown.port=$SHUTDOWN_PORT"
   JAVA_OPTS="$JAVA_OPTS -Djava.library.path=$CATALINA_HOME/lib/"
   JAVA_OPTS="$JAVA_OPTS -DLOG_BASE=$LOG_BASE"

   # MC Application Properties
   JAVA_OPTS="$JAVA_OPTS -Dapp.name=$SERVER_NAME"

   JAVA_OPTS="$JAVA_OPTS -noverify"
   JAVA_OPTS="$JAVA_OPTS -Xms1024m"
   JAVA_OPTS="$JAVA_OPTS -Xmx1024m"
   JAVA_OPTS="$JAVA_OPTS -XX:MetaspaceSize=512m"
   JAVA_OPTS="$JAVA_OPTS -XX:MaxMetaspaceSize=512m"
#   JAVA_OPTS="$JAVA_OPTS -Xss128k"

   JAVA_OPTS="$JAVA_OPTS -XX:+UseG1GC -XX:G1ReservePercent=20 -XX:InitiatingHeapOccupancyPercent=35"
   JAVA_OPTS="$JAVA_OPTS -XX:-UseCodeCacheFlushing"
   JAVA_OPTS="$JAVA_OPTS -XX:ReservedCodeCacheSize=512m"

   JAVA_OPTS="$JAVA_OPTS -XX:+DisableExplicitGC"
   JAVA_OPTS="$JAVA_OPTS -XX:+PrintAdaptiveSizePolicy"
   JAVA_OPTS="$JAVA_OPTS -XX:+UseLargePagesInMetaspace"

   JAVA_OPTS="$JAVA_OPTS -Dorg.apache.tomcat.websocket.DEFAULT_BUFFER_SIZE=32768"

#   JAVA_OPTS="$JAVA_OPTS -verbose:gc"
   JAVA_OPTS="$JAVA_OPTS -Xloggc:$LOG_BASE/gc.log"
   JAVA_OPTS="$JAVA_OPTS -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=10 -XX:GCLogFileSize=5M"
   JAVA_OPTS="$JAVA_OPTS -XX:+PrintGCDetails"
   JAVA_OPTS="$JAVA_OPTS -XX:+PrintGCTimeStamps"
   JAVA_OPTS="$JAVA_OPTS -XX:-PrintTenuringDistribution"
   JAVA_OPTS="$JAVA_OPTS -XX:+HeapDumpOnOutOfMemoryError"
   JAVA_OPTS="$JAVA_OPTS -XX:HeapDumpPath=$LOG_BASE/java_${SERVER_NAME}_pid_${DATE}.hprof"

   JAVA_OPTS="$JAVA_OPTS -Djava.net.preferIPv4Stack=true"
   JAVA_OPTS="$JAVA_OPTS -Djava.security.egd=file:/dev/urandom" 
   JAVA_OPTS="$JAVA_OPTS -Dsun.rmi.dgc.client.gcInterval=3600000"
   JAVA_OPTS="$JAVA_OPTS -Dsun.rmi.dgc.server.gcInterval=3600000"
   JAVA_OPTS="$JAVA_OPTS -Dsun.lang.ClassLoader.allowArraySyntax=true"

   JAVA_OPTS="$JAVA_OPTS -Dfile.encoding=UTF-8"

   JAVA_OPTS="$JAVA_OPTS -Dspring.profiles.active=prod"
   JAVA_OPTS="$JAVA_OPTS -DWEBSQUARE_HOME=/workspace/akapp/was/splace01/websquare_home/splace"

fi

#######################################
# Scouter APM configuration
#######################################
#   JAVA_OPTS="$JAVA_OPTS -javaagent:/opt/apm/scouter/agent.java/scouter.agent.jar"
#   JAVA_OPTS="$JAVA_OPTS -Dscouter.config=/opt/apm/scouter/agent.java/conf/rest-api.conf"


export JAVA_OPTS

CATALINA_OPTS="$CATALINA_OPTS -Dcom.sun.management.jmxremote"
CATALINA_OPTS="$CATALINA_OPTS -Dcom.sun.management.jmxremote=true"
CATALINA_OPTS="$CATALINA_OPTS -Dcom.sun.management.jmxremote.port=$JMX_PORT"
CATALINA_OPTS="$CATALINA_OPTS -Dcom.sun.management.jmxremote.ssl=false"
CATALINA_OPTS="$CATALINA_OPTS -Dcom.sun.management.jmxremote.authenticate=false"

export CATALINA_OPTS

echo "================================================"
echo "CATALINA_HOME=$CATALINA_HOME"
echo "SERVER_HOME=$CATALINA_BASE"
echo "HTTP_PORT=$HTTP_PORT"
echo "SSL_PORT=$SSL_PORT"
echo "AJP_PORT=$AJP_PORT"
echo "SHUTDOWN_PORT=$SHUTDOWN_PORT"
echo "================================================"
